==> jc-1.4.0.tar.gz: polyglot/ext/jl/qq/QQListToken.h <==
// public class polyglot.ext.jl.qq.QQListToken

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 833336880f80fc35 polyglot_ext_jl_qq_QQListToken
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_ext_jl_qq_QQListToken_H_
#define _JC_polyglot_ext_jl_qq_QQListToken_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$sub_refs	_jc_polyglot_ext_jl_qq_QQListToken$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs	_jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$refs	_jc_polyglot_ext_jl_qq_QQListToken$refs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$nonrefs	_jc_polyglot_ext_jl_qq_QQListToken$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$object	_jc_polyglot_ext_jl_qq_QQListToken$object;

typedef const struct _jc_polyglot_ext_jl_qq_QQListToken$vmethods	_jc_polyglot_ext_jl_qq_QQListToken$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_QQListToken$vtable	_jc_polyglot_ext_jl_qq_QQListToken$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_QQListToken$vtype	_jc_polyglot_ext_jl_qq_QQListToken$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_qq_QQListToken$method$_init$9705e2e73c33494c(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQListToken$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, jint);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_qq_QQListToken$method$list$3998e73e4316312d(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQListToken$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_qq_QQListToken$method_info$list$3998e73e4316312d;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_QQListToken$vmethods {
	struct _jc_object	*(*list$3998e73e4316312d)(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQListToken$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_qq_QQListToken$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_ext_jl_qq_QQListToken$vmethods	polyglot_ext_jl_qq_QQListToken;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_QQListToken$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_QQListToken$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQListToken$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQListToken$refs {
    _jc_polyglot_ext_jl_qq_QQListToken$sub_refs	polyglot_ext_jl_qq_QQListToken;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQListToken$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs	polyglot_ext_jl_qq_QQListToken;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_QQListToken$object {
	_jc_polyglot_ext_jl_qq_QQListToken$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_QQListToken$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_QQListToken$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_QQListToken$vtype _jc_polyglot_ext_jl_qq_QQListToken$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_QQListToken, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_QQListToken$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_QQListToken_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/qq/QQListToken.h <==
// public class polyglot.ext.jl.qq.QQListToken

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 833336880f80fc35 polyglot_ext_jl_qq_QQListToken
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Token

#include "polyglot/lex/Token.h"

#ifndef _JC_polyglot_ext_jl_qq_QQListToken_H_
#define _JC_polyglot_ext_jl_qq_QQListToken_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$sub_refs	_jc_polyglot_ext_jl_qq_QQListToken$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs	_jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$refs	_jc_polyglot_ext_jl_qq_QQListToken$refs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$nonrefs	_jc_polyglot_ext_jl_qq_QQListToken$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_QQListToken$object	_jc_polyglot_ext_jl_qq_QQListToken$object;

typedef const struct _jc_polyglot_ext_jl_qq_QQListToken$vmethods	_jc_polyglot_ext_jl_qq_QQListToken$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_QQListToken$vtable	_jc_polyglot_ext_jl_qq_QQListToken$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_QQListToken$vtype	_jc_polyglot_ext_jl_qq_QQListToken$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_qq_QQListToken$method$_init$9705e2e73c33494c(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQListToken$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_qq_QQListToken$method$list$3998e73e4316312d(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQListToken$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_qq_QQListToken$method_info$list$3998e73e4316312d;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_QQListToken$vmethods {
	struct _jc_object	*(*list$3998e73e4316312d)(_jc_env *, struct _jc_polyglot_ext_jl_qq_QQListToken$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_qq_QQListToken$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_ext_jl_qq_QQListToken$vmethods	polyglot_ext_jl_qq_QQListToken;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_QQListToken$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_QQListToken$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQListToken$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQListToken$refs {
    _jc_polyglot_ext_jl_qq_QQListToken$sub_refs	polyglot_ext_jl_qq_QQListToken;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_QQListToken$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_ext_jl_qq_QQListToken$sub_nonrefs	polyglot_ext_jl_qq_QQListToken;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_QQListToken$object {
	_jc_polyglot_ext_jl_qq_QQListToken$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_QQListToken$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_QQListToken$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_QQListToken$vtype _jc_polyglot_ext_jl_qq_QQListToken$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_QQListToken, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_QQListToken$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_QQListToken_H_ */
